from typing import ClassVar as _ClassVar
from typing import Iterable as _Iterable
from typing import Mapping as _Mapping
from typing import Optional as _Optional
from typing import Union as _Union

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import struct_pb2 as _struct_pb2
from google.protobuf import wrappers_pb2 as _wrappers_pb2
from google.protobuf.internal import containers as _containers
from omni.pro.protos.common import base_pb2 as _base_pb2
from omni.pro.protos.v1.stock import country_pb2 as _country_pb2
from omni.pro.protos.v1.stock import location_pb2 as _location_pb2
from omni.pro.protos.v1.stock import picking_type_pb2 as _picking_type_pb2

DESCRIPTOR: _descriptor.FileDescriptor

class Warehouse(_message.Message):
    __slots__ = [
        "id",
        "name",
        "code",
        "country",
        "territory_matrix_value",
        "address",
        "complement",
        "active",
        "delivery_steps",
        "reception_steps",
        "locality_available",
        "view_location_id",
        "loc_stock_id",
        "wh_input_stock_loc_id",
        "wh_qc_stock_loc_id",
        "wh_pack_stock_loc_id",
        "wh_output_stock_loc_id",
        "in_type_id",
        "int_type_id",
        "pick_type_id",
        "pack_type_id",
        "out_type_id",
        "object_audit",
    ]
    ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    CODE_FIELD_NUMBER: _ClassVar[int]
    COUNTRY_FIELD_NUMBER: _ClassVar[int]
    TERRITORY_MATRIX_VALUE_FIELD_NUMBER: _ClassVar[int]
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    COMPLEMENT_FIELD_NUMBER: _ClassVar[int]
    ACTIVE_FIELD_NUMBER: _ClassVar[int]
    DELIVERY_STEPS_FIELD_NUMBER: _ClassVar[int]
    RECEPTION_STEPS_FIELD_NUMBER: _ClassVar[int]
    LOCALITY_AVAILABLE_FIELD_NUMBER: _ClassVar[int]
    VIEW_LOCATION_ID_FIELD_NUMBER: _ClassVar[int]
    LOC_STOCK_ID_FIELD_NUMBER: _ClassVar[int]
    WH_INPUT_STOCK_LOC_ID_FIELD_NUMBER: _ClassVar[int]
    WH_QC_STOCK_LOC_ID_FIELD_NUMBER: _ClassVar[int]
    WH_PACK_STOCK_LOC_ID_FIELD_NUMBER: _ClassVar[int]
    WH_OUTPUT_STOCK_LOC_ID_FIELD_NUMBER: _ClassVar[int]
    IN_TYPE_ID_FIELD_NUMBER: _ClassVar[int]
    INT_TYPE_ID_FIELD_NUMBER: _ClassVar[int]
    PICK_TYPE_ID_FIELD_NUMBER: _ClassVar[int]
    PACK_TYPE_ID_FIELD_NUMBER: _ClassVar[int]
    OUT_TYPE_ID_FIELD_NUMBER: _ClassVar[int]
    OBJECT_AUDIT_FIELD_NUMBER: _ClassVar[int]
    id: int
    name: str
    code: str
    country: _country_pb2.Country
    territory_matrix_value: _struct_pb2.ListValue
    address: str
    complement: str
    active: _wrappers_pb2.BoolValue
    delivery_steps: str
    reception_steps: str
    locality_available: str
    view_location_id: _location_pb2.Location
    loc_stock_id: _location_pb2.Location
    wh_input_stock_loc_id: _location_pb2.Location
    wh_qc_stock_loc_id: _location_pb2.Location
    wh_pack_stock_loc_id: _location_pb2.Location
    wh_output_stock_loc_id: _location_pb2.Location
    in_type_id: _picking_type_pb2.PickingType
    int_type_id: _picking_type_pb2.PickingType
    pick_type_id: _picking_type_pb2.PickingType
    pack_type_id: _picking_type_pb2.PickingType
    out_type_id: _picking_type_pb2.PickingType
    object_audit: _base_pb2.ObjectAudit
    def __init__(
        self,
        id: _Optional[int] = ...,
        name: _Optional[str] = ...,
        code: _Optional[str] = ...,
        country: _Optional[_Union[_country_pb2.Country, _Mapping]] = ...,
        territory_matrix_value: _Optional[_Union[_struct_pb2.ListValue, _Mapping]] = ...,
        address: _Optional[str] = ...,
        complement: _Optional[str] = ...,
        active: _Optional[_Union[_wrappers_pb2.BoolValue, _Mapping]] = ...,
        delivery_steps: _Optional[str] = ...,
        reception_steps: _Optional[str] = ...,
        locality_available: _Optional[str] = ...,
        view_location_id: _Optional[_Union[_location_pb2.Location, _Mapping]] = ...,
        loc_stock_id: _Optional[_Union[_location_pb2.Location, _Mapping]] = ...,
        wh_input_stock_loc_id: _Optional[_Union[_location_pb2.Location, _Mapping]] = ...,
        wh_qc_stock_loc_id: _Optional[_Union[_location_pb2.Location, _Mapping]] = ...,
        wh_pack_stock_loc_id: _Optional[_Union[_location_pb2.Location, _Mapping]] = ...,
        wh_output_stock_loc_id: _Optional[_Union[_location_pb2.Location, _Mapping]] = ...,
        in_type_id: _Optional[_Union[_picking_type_pb2.PickingType, _Mapping]] = ...,
        int_type_id: _Optional[_Union[_picking_type_pb2.PickingType, _Mapping]] = ...,
        pick_type_id: _Optional[_Union[_picking_type_pb2.PickingType, _Mapping]] = ...,
        pack_type_id: _Optional[_Union[_picking_type_pb2.PickingType, _Mapping]] = ...,
        out_type_id: _Optional[_Union[_picking_type_pb2.PickingType, _Mapping]] = ...,
        object_audit: _Optional[_Union[_base_pb2.ObjectAudit, _Mapping]] = ...,
    ) -> None: ...

class WarehouseCreateRequest(_message.Message):
    __slots__ = [
        "name",
        "code",
        "country_code",
        "territory_matrix_value",
        "address",
        "complement",
        "delivery_steps",
        "reception_steps",
        "locality_available",
        "view_location_id",
        "loc_stock_id",
        "wh_input_stock_loc_id",
        "wh_qc_stock_loc_id",
        "wh_pack_stock_loc_id",
        "wh_output_stock_loc_id",
        "in_type_id",
        "int_type_id",
        "pick_type_id",
        "pack_type_id",
        "out_type_id",
        "context",
    ]
    NAME_FIELD_NUMBER: _ClassVar[int]
    CODE_FIELD_NUMBER: _ClassVar[int]
    COUNTRY_CODE_FIELD_NUMBER: _ClassVar[int]
    TERRITORY_MATRIX_VALUE_FIELD_NUMBER: _ClassVar[int]
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    COMPLEMENT_FIELD_NUMBER: _ClassVar[int]
    DELIVERY_STEPS_FIELD_NUMBER: _ClassVar[int]
    RECEPTION_STEPS_FIELD_NUMBER: _ClassVar[int]
    LOCALITY_AVAILABLE_FIELD_NUMBER: _ClassVar[int]
    VIEW_LOCATION_ID_FIELD_NUMBER: _ClassVar[int]
    LOC_STOCK_ID_FIELD_NUMBER: _ClassVar[int]
    WH_INPUT_STOCK_LOC_ID_FIELD_NUMBER: _ClassVar[int]
    WH_QC_STOCK_LOC_ID_FIELD_NUMBER: _ClassVar[int]
    WH_PACK_STOCK_LOC_ID_FIELD_NUMBER: _ClassVar[int]
    WH_OUTPUT_STOCK_LOC_ID_FIELD_NUMBER: _ClassVar[int]
    IN_TYPE_ID_FIELD_NUMBER: _ClassVar[int]
    INT_TYPE_ID_FIELD_NUMBER: _ClassVar[int]
    PICK_TYPE_ID_FIELD_NUMBER: _ClassVar[int]
    PACK_TYPE_ID_FIELD_NUMBER: _ClassVar[int]
    OUT_TYPE_ID_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    name: str
    code: str
    country_code: str
    territory_matrix_value: _struct_pb2.ListValue
    address: str
    complement: str
    delivery_steps: str
    reception_steps: str
    locality_available: str
    view_location_id: int
    loc_stock_id: int
    wh_input_stock_loc_id: int
    wh_qc_stock_loc_id: int
    wh_pack_stock_loc_id: int
    wh_output_stock_loc_id: int
    in_type_id: int
    int_type_id: int
    pick_type_id: int
    pack_type_id: int
    out_type_id: int
    context: _base_pb2.Context
    def __init__(
        self,
        name: _Optional[str] = ...,
        code: _Optional[str] = ...,
        country_code: _Optional[str] = ...,
        territory_matrix_value: _Optional[_Union[_struct_pb2.ListValue, _Mapping]] = ...,
        address: _Optional[str] = ...,
        complement: _Optional[str] = ...,
        delivery_steps: _Optional[str] = ...,
        reception_steps: _Optional[str] = ...,
        locality_available: _Optional[str] = ...,
        view_location_id: _Optional[int] = ...,
        loc_stock_id: _Optional[int] = ...,
        wh_input_stock_loc_id: _Optional[int] = ...,
        wh_qc_stock_loc_id: _Optional[int] = ...,
        wh_pack_stock_loc_id: _Optional[int] = ...,
        wh_output_stock_loc_id: _Optional[int] = ...,
        in_type_id: _Optional[int] = ...,
        int_type_id: _Optional[int] = ...,
        pick_type_id: _Optional[int] = ...,
        pack_type_id: _Optional[int] = ...,
        out_type_id: _Optional[int] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class WarehouseCreateResponse(_message.Message):
    __slots__ = ["response_standard", "warehouse"]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    WAREHOUSE_FIELD_NUMBER: _ClassVar[int]
    response_standard: _base_pb2.ResponseStandard
    warehouse: Warehouse
    def __init__(
        self,
        response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...,
        warehouse: _Optional[_Union[Warehouse, _Mapping]] = ...,
    ) -> None: ...

class WarehouseReadRequest(_message.Message):
    __slots__ = ["group_by", "sort_by", "fields", "filter", "paginated", "id", "context"]
    GROUP_BY_FIELD_NUMBER: _ClassVar[int]
    SORT_BY_FIELD_NUMBER: _ClassVar[int]
    FIELDS_FIELD_NUMBER: _ClassVar[int]
    FILTER_FIELD_NUMBER: _ClassVar[int]
    PAGINATED_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    group_by: _containers.RepeatedCompositeFieldContainer[_base_pb2.GroupBy]
    sort_by: _base_pb2.SortBy
    fields: _base_pb2.Fields
    filter: _base_pb2.Filter
    paginated: _base_pb2.Paginated
    id: int
    context: _base_pb2.Context
    def __init__(
        self,
        group_by: _Optional[_Iterable[_Union[_base_pb2.GroupBy, _Mapping]]] = ...,
        sort_by: _Optional[_Union[_base_pb2.SortBy, _Mapping]] = ...,
        fields: _Optional[_Union[_base_pb2.Fields, _Mapping]] = ...,
        filter: _Optional[_Union[_base_pb2.Filter, _Mapping]] = ...,
        paginated: _Optional[_Union[_base_pb2.Paginated, _Mapping]] = ...,
        id: _Optional[int] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class WarehouseReadResponse(_message.Message):
    __slots__ = ["response_standard", "meta_data", "warehouses"]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    META_DATA_FIELD_NUMBER: _ClassVar[int]
    WAREHOUSES_FIELD_NUMBER: _ClassVar[int]
    response_standard: _base_pb2.ResponseStandard
    meta_data: _base_pb2.MetaData
    warehouses: _containers.RepeatedCompositeFieldContainer[Warehouse]
    def __init__(
        self,
        response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...,
        meta_data: _Optional[_Union[_base_pb2.MetaData, _Mapping]] = ...,
        warehouses: _Optional[_Iterable[_Union[Warehouse, _Mapping]]] = ...,
    ) -> None: ...

class WarehouseUpdateRequest(_message.Message):
    __slots__ = ["warehouse", "context"]
    WAREHOUSE_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    warehouse: Warehouse
    context: _base_pb2.Context
    def __init__(
        self,
        warehouse: _Optional[_Union[Warehouse, _Mapping]] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class WarehouseUpdateResponse(_message.Message):
    __slots__ = ["response_standard", "warehouse"]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    WAREHOUSE_FIELD_NUMBER: _ClassVar[int]
    response_standard: _base_pb2.ResponseStandard
    warehouse: Warehouse
    def __init__(
        self,
        response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...,
        warehouse: _Optional[_Union[Warehouse, _Mapping]] = ...,
    ) -> None: ...

class WarehouseDeleteRequest(_message.Message):
    __slots__ = ["id", "context"]
    ID_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    id: int
    context: _base_pb2.Context
    def __init__(
        self, id: _Optional[int] = ..., context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...
    ) -> None: ...

class WarehouseDeleteResponse(_message.Message):
    __slots__ = ["response_standard"]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    response_standard: _base_pb2.ResponseStandard
    def __init__(self, response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: v1/sales/channel.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from omni.pro.protos.common import base_pb2 as common_dot_base__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x16v1/sales/channel.proto\x12!pro.omni.oms.api.v1.sales.channel\x1a\x11\x63ommon/base.proto\x1a\x1egoogle/protobuf/wrappers.proto"\x9e\x01\n\x07\x43hannel\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04\x63ode\x18\x03 \x01(\t\x12*\n\x06\x61\x63tive\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12?\n\x0cobject_audit\x18\x05 \x01(\x0b\x32).pro.omni.oms.api.common.base.ObjectAudit"j\n\x14\x43hannelCreateRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\x12\x36\n\x07\x63ontext\x18\x03 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x9f\x01\n\x15\x43hannelCreateResponse\x12;\n\x07\x63hannel\x18\x01 \x01(\x0b\x32*.pro.omni.oms.api.v1.sales.channel.Channel\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\xf0\x02\n\x12\x43hannelReadRequest\x12\x37\n\x08group_by\x18\x01 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x05 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\n\n\x02id\x18\x06 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xd9\x01\n\x13\x43hannelReadResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x39\n\tmeta_data\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData\x12<\n\x08\x63hannels\x18\x03 \x03(\x0b\x32*.pro.omni.oms.api.v1.sales.channel.Channel"\x8b\x01\n\x14\x43hannelUpdateRequest\x12;\n\x07\x63hannel\x18\x01 \x01(\x0b\x32*.pro.omni.oms.api.v1.sales.channel.Channel\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x9f\x01\n\x15\x43hannelUpdateResponse\x12;\n\x07\x63hannel\x18\x01 \x01(\x0b\x32*.pro.omni.oms.api.v1.sales.channel.Channel\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"Z\n\x14\x43hannelDeleteRequest\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"b\n\x15\x43hannelDeleteResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard2\x9d\x04\n\x0e\x43hannelService\x12\x82\x01\n\rChannelCreate\x12\x37.pro.omni.oms.api.v1.sales.channel.ChannelCreateRequest\x1a\x38.pro.omni.oms.api.v1.sales.channel.ChannelCreateResponse\x12|\n\x0b\x43hannelRead\x12\x35.pro.omni.oms.api.v1.sales.channel.ChannelReadRequest\x1a\x36.pro.omni.oms.api.v1.sales.channel.ChannelReadResponse\x12\x82\x01\n\rChannelUpdate\x12\x37.pro.omni.oms.api.v1.sales.channel.ChannelUpdateRequest\x1a\x38.pro.omni.oms.api.v1.sales.channel.ChannelUpdateResponse\x12\x82\x01\n\rChannelDelete\x12\x37.pro.omni.oms.api.v1.sales.channel.ChannelDeleteRequest\x1a\x38.pro.omni.oms.api.v1.sales.channel.ChannelDeleteResponseb\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "v1.sales.channel_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _globals["_CHANNEL"]._serialized_start = 113
    _globals["_CHANNEL"]._serialized_end = 271
    _globals["_CHANNELCREATEREQUEST"]._serialized_start = 273
    _globals["_CHANNELCREATEREQUEST"]._serialized_end = 379
    _globals["_CHANNELCREATERESPONSE"]._serialized_start = 382
    _globals["_CHANNELCREATERESPONSE"]._serialized_end = 541
    _globals["_CHANNELREADREQUEST"]._serialized_start = 544
    _globals["_CHANNELREADREQUEST"]._serialized_end = 912
    _globals["_CHANNELREADRESPONSE"]._serialized_start = 915
    _globals["_CHANNELREADRESPONSE"]._serialized_end = 1132
    _globals["_CHANNELUPDATEREQUEST"]._serialized_start = 1135
    _globals["_CHANNELUPDATEREQUEST"]._serialized_end = 1274
    _globals["_CHANNELUPDATERESPONSE"]._serialized_start = 1277
    _globals["_CHANNELUPDATERESPONSE"]._serialized_end = 1436
    _globals["_CHANNELDELETEREQUEST"]._serialized_start = 1438
    _globals["_CHANNELDELETEREQUEST"]._serialized_end = 1528
    _globals["_CHANNELDELETERESPONSE"]._serialized_start = 1530
    _globals["_CHANNELDELETERESPONSE"]._serialized_end = 1628
    _globals["_CHANNELSERVICE"]._serialized_start = 1631
    _globals["_CHANNELSERVICE"]._serialized_end = 2172
# @@protoc_insertion_point(module_scope)



import logging
import traceback


def configure_logger(name) -> logging.Logger:
    logger = logging.getLogger(name=name)
    logger.setLevel(logging.DEBUG)
    formatter = logging.Formatter("%(asctime)s - %(name)s - %(levelname)s - %(message)s")
    console_handler = logging.StreamHandler()
    console_handler.setLevel(logging.DEBUG)
    console_handler.setFormatter(formatter)
    logger.addHandler(console_handler)
    return logger


class LoggerTraceback(object):
    @staticmethod
    def error(msg: str, e: Exception, logger: logging.Logger = None) -> str:
        if logger is None:
            logger = configure_logger(name=__name__)
        if not isinstance(e, Exception):
            e = Exception(str(e))
        msg_error = "{msg} - {ex}".format(msg=msg, ex=e.__class__)
        tb = traceback.format_exc()
        logger.error(f"{msg_error}: {tb}")
        return msg_error



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: v1/rules/delivery_price_delivery_method.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from omni.pro.protos.common import base_pb2 as common_dot_base__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n-v1/rules/delivery_price_delivery_method.proto\x12\x38pro.omni.oms.api.v1.rules.delivery_price_delivery_method\x1a\x11\x63ommon/base.proto"\xb1\x01\n\x1b\x44\x65liveryPriceDeliveryMethod\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x19\n\x11\x64\x65livery_price_id\x18\x02 \x01(\x05\x12\x1a\n\x12\x64\x65livery_method_id\x18\x03 \x01(\x05\x12\x0e\n\x06\x61\x63tive\x18\x04 \x01(\x08\x12?\n\x0cobject_audit\x18\x05 \x01(\x0b\x32).pro.omni.oms.api.common.base.ObjectAudit"\x99\x01\n(DeliveryPriceDeliveryMethodCreateRequest\x12\x19\n\x11\x64\x65livery_price_id\x18\x01 \x01(\x05\x12\x1a\n\x12\x64\x65livery_method_id\x18\x02 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x03 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xf5\x01\n)DeliveryPriceDeliveryMethodCreateResponse\x12}\n\x1e\x64\x65livery_price_delivery_method\x18\x01 \x01(\x0b\x32U.pro.omni.oms.api.v1.rules.delivery_price_delivery_method.DeliveryPriceDeliveryMethod\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\x84\x03\n&DeliveryPriceDeliveryMethodReadRequest\x12\x37\n\x08group_by\x18\x01 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x05 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\n\n\x02id\x18\x06 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xae\x02\n\'DeliveryPriceDeliveryMethodReadResponse\x12}\n\x1e\x64\x65livery_price_delivery_method\x18\x01 \x03(\x0b\x32U.pro.omni.oms.api.v1.rules.delivery_price_delivery_method.DeliveryPriceDeliveryMethod\x12\x39\n\tmeta_data\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData\x12I\n\x11response_standard\x18\x03 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\xe1\x01\n(DeliveryPriceDeliveryMethodUpdateRequest\x12}\n\x1e\x64\x65livery_price_delivery_method\x18\x01 \x01(\x0b\x32U.pro.omni.oms.api.v1.rules.delivery_price_delivery_method.DeliveryPriceDeliveryMethod\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xf5\x01\n)DeliveryPriceDeliveryMethodUpdateResponse\x12}\n\x1e\x64\x65livery_price_delivery_method\x18\x01 \x01(\x0b\x32U.pro.omni.oms.api.v1.rules.delivery_price_delivery_method.DeliveryPriceDeliveryMethod\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"n\n(DeliveryPriceDeliveryMethodDeleteRequest\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"v\n)DeliveryPriceDeliveryMethodDeleteResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard2\xe2\x07\n"DeliveryPriceDeliveryMethodService\x12\xee\x01\n!DeliveryPriceDeliveryMethodCreate\x12\x62.pro.omni.oms.api.v1.rules.delivery_price_delivery_method.DeliveryPriceDeliveryMethodCreateRequest\x1a\x63.pro.omni.oms.api.v1.rules.delivery_price_delivery_method.DeliveryPriceDeliveryMethodCreateResponse"\x00\x12\xe8\x01\n\x1f\x44\x65liveryPriceDeliveryMethodRead\x12`.pro.omni.oms.api.v1.rules.delivery_price_delivery_method.DeliveryPriceDeliveryMethodReadRequest\x1a\x61.pro.omni.oms.api.v1.rules.delivery_price_delivery_method.DeliveryPriceDeliveryMethodReadResponse"\x00\x12\xee\x01\n!DeliveryPriceDeliveryMethodUpdate\x12\x62.pro.omni.oms.api.v1.rules.delivery_price_delivery_method.DeliveryPriceDeliveryMethodUpdateRequest\x1a\x63.pro.omni.oms.api.v1.rules.delivery_price_delivery_method.DeliveryPriceDeliveryMethodUpdateResponse"\x00\x12\xee\x01\n!DeliveryPriceDeliveryMethodDelete\x12\x62.pro.omni.oms.api.v1.rules.delivery_price_delivery_method.DeliveryPriceDeliveryMethodDeleteRequest\x1a\x63.pro.omni.oms.api.v1.rules.delivery_price_delivery_method.DeliveryPriceDeliveryMethodDeleteResponse"\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "v1.rules.delivery_price_delivery_method_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _globals["_DELIVERYPRICEDELIVERYMETHOD"]._serialized_start = 127
    _globals["_DELIVERYPRICEDELIVERYMETHOD"]._serialized_end = 304
    _globals["_DELIVERYPRICEDELIVERYMETHODCREATEREQUEST"]._serialized_start = 307
    _globals["_DELIVERYPRICEDELIVERYMETHODCREATEREQUEST"]._serialized_end = 460
    _globals["_DELIVERYPRICEDELIVERYMETHODCREATERESPONSE"]._serialized_start = 463
    _globals["_DELIVERYPRICEDELIVERYMETHODCREATERESPONSE"]._serialized_end = 708
    _globals["_DELIVERYPRICEDELIVERYMETHODREADREQUEST"]._serialized_start = 711
    _globals["_DELIVERYPRICEDELIVERYMETHODREADREQUEST"]._serialized_end = 1099
    _globals["_DELIVERYPRICEDELIVERYMETHODREADRESPONSE"]._serialized_start = 1102
    _globals["_DELIVERYPRICEDELIVERYMETHODREADRESPONSE"]._serialized_end = 1404
    _globals["_DELIVERYPRICEDELIVERYMETHODUPDATEREQUEST"]._serialized_start = 1407
    _globals["_DELIVERYPRICEDELIVERYMETHODUPDATEREQUEST"]._serialized_end = 1632
    _globals["_DELIVERYPRICEDELIVERYMETHODUPDATERESPONSE"]._serialized_start = 1635
    _globals["_DELIVERYPRICEDELIVERYMETHODUPDATERESPONSE"]._serialized_end = 1880
    _globals["_DELIVERYPRICEDELIVERYMETHODDELETEREQUEST"]._serialized_start = 1882
    _globals["_DELIVERYPRICEDELIVERYMETHODDELETEREQUEST"]._serialized_end = 1992
    _globals["_DELIVERYPRICEDELIVERYMETHODDELETERESPONSE"]._serialized_start = 1994
    _globals["_DELIVERYPRICEDELIVERYMETHODDELETERESPONSE"]._serialized_end = 2112
    _globals["_DELIVERYPRICEDELIVERYMETHODSERVICE"]._serialized_start = 2115
    _globals["_DELIVERYPRICEDELIVERYMETHODSERVICE"]._serialized_end = 3109
# @@protoc_insertion_point(module_scope)



from typing import ClassVar as _ClassVar
from typing import Iterable as _Iterable
from typing import Mapping as _Mapping
from typing import Optional as _Optional
from typing import Union as _Union

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import wrappers_pb2 as _wrappers_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from omni.pro.protos.common import base_pb2 as _base_pb2
from omni.pro.protos.v1.rules import warehouse_hierarchy_pb2 as _warehouse_hierarchy_pb2

DESCRIPTOR: _descriptor.FileDescriptor

class SortBy(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = []
    ASC: _ClassVar[SortBy]
    DESC: _ClassVar[SortBy]

ASC: SortBy
DESC: SortBy

class DeliveryWarehouse(_message.Message):
    __slots__ = ["id", "name", "hierarchi_warehouse_sort_by", "transfer_warehouses", "active", "object_audit"]
    ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    HIERARCHI_WAREHOUSE_SORT_BY_FIELD_NUMBER: _ClassVar[int]
    TRANSFER_WAREHOUSES_FIELD_NUMBER: _ClassVar[int]
    ACTIVE_FIELD_NUMBER: _ClassVar[int]
    OBJECT_AUDIT_FIELD_NUMBER: _ClassVar[int]
    id: str
    name: str
    hierarchi_warehouse_sort_by: SortBy
    transfer_warehouses: _containers.RepeatedCompositeFieldContainer[_warehouse_hierarchy_pb2.WarehouseHierarchy]
    active: _wrappers_pb2.BoolValue
    object_audit: _base_pb2.ObjectAudit
    def __init__(
        self,
        id: _Optional[str] = ...,
        name: _Optional[str] = ...,
        hierarchi_warehouse_sort_by: _Optional[_Union[SortBy, str]] = ...,
        transfer_warehouses: _Optional[_Iterable[_Union[_warehouse_hierarchy_pb2.WarehouseHierarchy, _Mapping]]] = ...,
        active: _Optional[_Union[_wrappers_pb2.BoolValue, _Mapping]] = ...,
        object_audit: _Optional[_Union[_base_pb2.ObjectAudit, _Mapping]] = ...,
    ) -> None: ...

class DeliveryWarehouseCreateRequest(_message.Message):
    __slots__ = ["name", "transfer_warehouse_ids", "hierarchi_warehouse_sort_by", "context"]
    NAME_FIELD_NUMBER: _ClassVar[int]
    TRANSFER_WAREHOUSE_IDS_FIELD_NUMBER: _ClassVar[int]
    HIERARCHI_WAREHOUSE_SORT_BY_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    name: str
    transfer_warehouse_ids: _containers.RepeatedScalarFieldContainer[str]
    hierarchi_warehouse_sort_by: SortBy
    context: _base_pb2.Context
    def __init__(
        self,
        name: _Optional[str] = ...,
        transfer_warehouse_ids: _Optional[_Iterable[str]] = ...,
        hierarchi_warehouse_sort_by: _Optional[_Union[SortBy, str]] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class DeliveryWarehouseCreateResponse(_message.Message):
    __slots__ = ["delivery_warehouse", "response_standard"]
    DELIVERY_WAREHOUSE_FIELD_NUMBER: _ClassVar[int]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    delivery_warehouse: DeliveryWarehouse
    response_standard: _base_pb2.ResponseStandard
    def __init__(
        self,
        delivery_warehouse: _Optional[_Union[DeliveryWarehouse, _Mapping]] = ...,
        response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...,
    ) -> None: ...

class DeliveryWarehouseReadRequest(_message.Message):
    __slots__ = ["group_by", "sort_by", "fields", "filter", "paginated", "id", "context"]
    GROUP_BY_FIELD_NUMBER: _ClassVar[int]
    SORT_BY_FIELD_NUMBER: _ClassVar[int]
    FIELDS_FIELD_NUMBER: _ClassVar[int]
    FILTER_FIELD_NUMBER: _ClassVar[int]
    PAGINATED_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    group_by: _containers.RepeatedCompositeFieldContainer[_base_pb2.GroupBy]
    sort_by: _base_pb2.SortBy
    fields: _base_pb2.Fields
    filter: _base_pb2.Filter
    paginated: _base_pb2.Paginated
    id: str
    context: _base_pb2.Context
    def __init__(
        self,
        group_by: _Optional[_Iterable[_Union[_base_pb2.GroupBy, _Mapping]]] = ...,
        sort_by: _Optional[_Union[_base_pb2.SortBy, _Mapping]] = ...,
        fields: _Optional[_Union[_base_pb2.Fields, _Mapping]] = ...,
        filter: _Optional[_Union[_base_pb2.Filter, _Mapping]] = ...,
        paginated: _Optional[_Union[_base_pb2.Paginated, _Mapping]] = ...,
        id: _Optional[str] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class DeliveryWarehouseReadResponse(_message.Message):
    __slots__ = ["delivery_warehouses", "meta_data", "response_standard"]
    DELIVERY_WAREHOUSES_FIELD_NUMBER: _ClassVar[int]
    META_DATA_FIELD_NUMBER: _ClassVar[int]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    delivery_warehouses: _containers.RepeatedCompositeFieldContainer[DeliveryWarehouse]
    meta_data: _base_pb2.MetaData
    response_standard: _base_pb2.ResponseStandard
    def __init__(
        self,
        delivery_warehouses: _Optional[_Iterable[_Union[DeliveryWarehouse, _Mapping]]] = ...,
        meta_data: _Optional[_Union[_base_pb2.MetaData, _Mapping]] = ...,
        response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...,
    ) -> None: ...

class DeliveryWarehouseUpdateRequest(_message.Message):
    __slots__ = ["delivery_warehouse", "context"]
    DELIVERY_WAREHOUSE_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    delivery_warehouse: DeliveryWarehouse
    context: _base_pb2.Context
    def __init__(
        self,
        delivery_warehouse: _Optional[_Union[DeliveryWarehouse, _Mapping]] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class DeliveryWarehouseUpdateResponse(_message.Message):
    __slots__ = ["delivery_warehouse", "response_standard"]
    DELIVERY_WAREHOUSE_FIELD_NUMBER: _ClassVar[int]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    delivery_warehouse: DeliveryWarehouse
    response_standard: _base_pb2.ResponseStandard
    def __init__(
        self,
        delivery_warehouse: _Optional[_Union[DeliveryWarehouse, _Mapping]] = ...,
        response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...,
    ) -> None: ...

class DeliveryWarehouseDeleteRequest(_message.Message):
    __slots__ = ["id", "context"]
    ID_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    id: str
    context: _base_pb2.Context
    def __init__(
        self, id: _Optional[str] = ..., context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...
    ) -> None: ...

class DeliveryWarehouseDeleteResponse(_message.Message):
    __slots__ = ["response_standard"]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    response_standard: _base_pb2.ResponseStandard
    def __init__(self, response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...) -> None: ...



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
from omni.pro.protos.v1.rules import schedule_work_pb2 as v1_dot_rules_dot_schedule__work__pb2


class ScheduleWorkServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ScheduleWorkCreate = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.schedule_work.ScheduleWorkService/ScheduleWorkCreate",
            request_serializer=v1_dot_rules_dot_schedule__work__pb2.ScheduleWorkCreateRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_schedule__work__pb2.ScheduleWorkCreateResponse.FromString,
        )
        self.ScheduleWorkRead = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.schedule_work.ScheduleWorkService/ScheduleWorkRead",
            request_serializer=v1_dot_rules_dot_schedule__work__pb2.ScheduleWorkReadRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_schedule__work__pb2.ScheduleWorkReadResponse.FromString,
        )
        self.ScheduleWorkUpdate = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.schedule_work.ScheduleWorkService/ScheduleWorkUpdate",
            request_serializer=v1_dot_rules_dot_schedule__work__pb2.ScheduleWorkUpdateRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_schedule__work__pb2.ScheduleWorkUpdateResponse.FromString,
        )
        self.ScheduleWorkDelete = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.schedule_work.ScheduleWorkService/ScheduleWorkDelete",
            request_serializer=v1_dot_rules_dot_schedule__work__pb2.ScheduleWorkDeleteRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_schedule__work__pb2.ScheduleWorkDeleteResponse.FromString,
        )


class ScheduleWorkServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ScheduleWorkCreate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def ScheduleWorkRead(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def ScheduleWorkUpdate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def ScheduleWorkDelete(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_ScheduleWorkServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "ScheduleWorkCreate": grpc.unary_unary_rpc_method_handler(
            servicer.ScheduleWorkCreate,
            request_deserializer=v1_dot_rules_dot_schedule__work__pb2.ScheduleWorkCreateRequest.FromString,
            response_serializer=v1_dot_rules_dot_schedule__work__pb2.ScheduleWorkCreateResponse.SerializeToString,
        ),
        "ScheduleWorkRead": grpc.unary_unary_rpc_method_handler(
            servicer.ScheduleWorkRead,
            request_deserializer=v1_dot_rules_dot_schedule__work__pb2.ScheduleWorkReadRequest.FromString,
            response_serializer=v1_dot_rules_dot_schedule__work__pb2.ScheduleWorkReadResponse.SerializeToString,
        ),
        "ScheduleWorkUpdate": grpc.unary_unary_rpc_method_handler(
            servicer.ScheduleWorkUpdate,
            request_deserializer=v1_dot_rules_dot_schedule__work__pb2.ScheduleWorkUpdateRequest.FromString,
            response_serializer=v1_dot_rules_dot_schedule__work__pb2.ScheduleWorkUpdateResponse.SerializeToString,
        ),
        "ScheduleWorkDelete": grpc.unary_unary_rpc_method_handler(
            servicer.ScheduleWorkDelete,
            request_deserializer=v1_dot_rules_dot_schedule__work__pb2.ScheduleWorkDeleteRequest.FromString,
            response_serializer=v1_dot_rules_dot_schedule__work__pb2.ScheduleWorkDeleteResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        "pro.omni.oms.api.v1.rules.schedule_work.ScheduleWorkService", rpc_method_handlers
    )
    server.add_generic_rpc_handlers((generic_handler,))


# This class is part of an EXPERIMENTAL API.
class ScheduleWorkService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ScheduleWorkCreate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.schedule_work.ScheduleWorkService/ScheduleWorkCreate",
            v1_dot_rules_dot_schedule__work__pb2.ScheduleWorkCreateRequest.SerializeToString,
            v1_dot_rules_dot_schedule__work__pb2.ScheduleWorkCreateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def ScheduleWorkRead(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.schedule_work.ScheduleWorkService/ScheduleWorkRead",
            v1_dot_rules_dot_schedule__work__pb2.ScheduleWorkReadRequest.SerializeToString,
            v1_dot_rules_dot_schedule__work__pb2.ScheduleWorkReadResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def ScheduleWorkUpdate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.schedule_work.ScheduleWorkService/ScheduleWorkUpdate",
            v1_dot_rules_dot_schedule__work__pb2.ScheduleWorkUpdateRequest.SerializeToString,
            v1_dot_rules_dot_schedule__work__pb2.ScheduleWorkUpdateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def ScheduleWorkDelete(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.schedule_work.ScheduleWorkService/ScheduleWorkDelete",
            v1_dot_rules_dot_schedule__work__pb2.ScheduleWorkDeleteRequest.SerializeToString,
            v1_dot_rules_dot_schedule__work__pb2.ScheduleWorkDeleteResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
from omni.pro.protos.v1.utilities import document_type_pb2 as v1_dot_utilities_dot_document__type__pb2


class DocumentTypeServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.DocumentTypeAdd = channel.unary_unary(
            "/pro.omni.oms.api.v1.utilities.document_type.DocumentTypeService/DocumentTypeAdd",
            request_serializer=v1_dot_utilities_dot_document__type__pb2.DocumentTypeAddRequest.SerializeToString,
            response_deserializer=v1_dot_utilities_dot_document__type__pb2.DocumentTypeAddResponse.FromString,
        )
        self.DocumentTypeRead = channel.unary_unary(
            "/pro.omni.oms.api.v1.utilities.document_type.DocumentTypeService/DocumentTypeRead",
            request_serializer=v1_dot_utilities_dot_document__type__pb2.DocumentTypeReadRequest.SerializeToString,
            response_deserializer=v1_dot_utilities_dot_document__type__pb2.DocumentTypeReadResponse.FromString,
        )
        self.DocumentTypeUpdate = channel.unary_unary(
            "/pro.omni.oms.api.v1.utilities.document_type.DocumentTypeService/DocumentTypeUpdate",
            request_serializer=v1_dot_utilities_dot_document__type__pb2.DocumentTypeUpdateRequest.SerializeToString,
            response_deserializer=v1_dot_utilities_dot_document__type__pb2.DocumentTypeUpdateResponse.FromString,
        )
        self.DocumentTypeDelete = channel.unary_unary(
            "/pro.omni.oms.api.v1.utilities.document_type.DocumentTypeService/DocumentTypeDelete",
            request_serializer=v1_dot_utilities_dot_document__type__pb2.DocumentTypeDeleteRequest.SerializeToString,
            response_deserializer=v1_dot_utilities_dot_document__type__pb2.DocumentTypeDeleteResponse.FromString,
        )


class DocumentTypeServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def DocumentTypeAdd(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def DocumentTypeRead(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def DocumentTypeUpdate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def DocumentTypeDelete(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_DocumentTypeServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "DocumentTypeAdd": grpc.unary_unary_rpc_method_handler(
            servicer.DocumentTypeAdd,
            request_deserializer=v1_dot_utilities_dot_document__type__pb2.DocumentTypeAddRequest.FromString,
            response_serializer=v1_dot_utilities_dot_document__type__pb2.DocumentTypeAddResponse.SerializeToString,
        ),
        "DocumentTypeRead": grpc.unary_unary_rpc_method_handler(
            servicer.DocumentTypeRead,
            request_deserializer=v1_dot_utilities_dot_document__type__pb2.DocumentTypeReadRequest.FromString,
            response_serializer=v1_dot_utilities_dot_document__type__pb2.DocumentTypeReadResponse.SerializeToString,
        ),
        "DocumentTypeUpdate": grpc.unary_unary_rpc_method_handler(
            servicer.DocumentTypeUpdate,
            request_deserializer=v1_dot_utilities_dot_document__type__pb2.DocumentTypeUpdateRequest.FromString,
            response_serializer=v1_dot_utilities_dot_document__type__pb2.DocumentTypeUpdateResponse.SerializeToString,
        ),
        "DocumentTypeDelete": grpc.unary_unary_rpc_method_handler(
            servicer.DocumentTypeDelete,
            request_deserializer=v1_dot_utilities_dot_document__type__pb2.DocumentTypeDeleteRequest.FromString,
            response_serializer=v1_dot_utilities_dot_document__type__pb2.DocumentTypeDeleteResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        "pro.omni.oms.api.v1.utilities.document_type.DocumentTypeService", rpc_method_handlers
    )
    server.add_generic_rpc_handlers((generic_handler,))


# This class is part of an EXPERIMENTAL API.
class DocumentTypeService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def DocumentTypeAdd(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.utilities.document_type.DocumentTypeService/DocumentTypeAdd",
            v1_dot_utilities_dot_document__type__pb2.DocumentTypeAddRequest.SerializeToString,
            v1_dot_utilities_dot_document__type__pb2.DocumentTypeAddResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def DocumentTypeRead(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.utilities.document_type.DocumentTypeService/DocumentTypeRead",
            v1_dot_utilities_dot_document__type__pb2.DocumentTypeReadRequest.SerializeToString,
            v1_dot_utilities_dot_document__type__pb2.DocumentTypeReadResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def DocumentTypeUpdate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.utilities.document_type.DocumentTypeService/DocumentTypeUpdate",
            v1_dot_utilities_dot_document__type__pb2.DocumentTypeUpdateRequest.SerializeToString,
            v1_dot_utilities_dot_document__type__pb2.DocumentTypeUpdateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def DocumentTypeDelete(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.utilities.document_type.DocumentTypeService/DocumentTypeDelete",
            v1_dot_utilities_dot_document__type__pb2.DocumentTypeDeleteRequest.SerializeToString,
            v1_dot_utilities_dot_document__type__pb2.DocumentTypeDeleteResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )



from pathlib import Path
from setuptools import find_packages, setup

# The directory containing this file
HERE = Path(__file__).parent

# The text of the README file
README = (HERE / "README.md").read_text()
DESCRIPTION = "Python library designed to be a utility for OMS microservices"
VERSION = "0.1.46"
PACKAGE_NAME = "omni-pro"
AUTHOR = "OMNI.PRO"
AUTHOR_EMAIL = "development@omni.pro"
URL = "https://github.com/Omnipro-Solutions/saas-ms-library"
INSTALL_REQUIRES = [
    "protobuf==4.23.4",
    "grpcio==1.56.0",
    "grpcio-tools==1.56.0",
    "boto3==1.28.4",
    "mongoengine==0.27.0",
    "marshmallow==3.19.0",
    "hiredis==2.2.3",
    "redis==4.6.0",
    "peewee==3.16.2",
    "fakeredis[json]==2.17.0",
    "SQLAlchemy==2.0.19",
]
# with open(HERE / "requirements.txt") as f:
#     INSTALL_REQUIRES = f.read().splitlines()

# This call to setup() does all the work
setup(
    name=PACKAGE_NAME,
    version=VERSION,
    description=DESCRIPTION,
    long_description=README,
    long_description_content_type="text/markdown",
    url=URL,
    author=AUTHOR,
    author_email=AUTHOR_EMAIL,
    license="MIT",
    packages=find_packages(exclude=("tests",)),
    package_data={"": ["*.pyi", "data/*.csv"]},
    include_package_data=True,
    install_requires=INSTALL_REQUIRES,
    classifiers=[
        "Development Status :: 3 - Alpha",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 3.9",
    ],
    extras_require={
        "dev": [
            "pytest",
        ]
    },
    test_suite="tests",
    python_requires=">=3.9",
)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
from omni.pro.protos.v1.sales import sale_pb2 as v1_dot_sales_dot_sale__pb2


class SaleServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.SaleCreate = channel.unary_unary(
            "/pro.omni.oms.api.v1.sales.sale.SaleService/SaleCreate",
            request_serializer=v1_dot_sales_dot_sale__pb2.SaleCreateRequest.SerializeToString,
            response_deserializer=v1_dot_sales_dot_sale__pb2.SaleCreateResponse.FromString,
        )
        self.SaleRead = channel.unary_unary(
            "/pro.omni.oms.api.v1.sales.sale.SaleService/SaleRead",
            request_serializer=v1_dot_sales_dot_sale__pb2.SaleReadRequest.SerializeToString,
            response_deserializer=v1_dot_sales_dot_sale__pb2.SaleReadResponse.FromString,
        )
        self.SaleUpdate = channel.unary_unary(
            "/pro.omni.oms.api.v1.sales.sale.SaleService/SaleUpdate",
            request_serializer=v1_dot_sales_dot_sale__pb2.SaleUpdateRequest.SerializeToString,
            response_deserializer=v1_dot_sales_dot_sale__pb2.SaleUpdateResponse.FromString,
        )
        self.SaleDelete = channel.unary_unary(
            "/pro.omni.oms.api.v1.sales.sale.SaleService/SaleDelete",
            request_serializer=v1_dot_sales_dot_sale__pb2.SaleDeleteRequest.SerializeToString,
            response_deserializer=v1_dot_sales_dot_sale__pb2.SaleDeleteResponse.FromString,
        )


class SaleServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def SaleCreate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def SaleRead(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def SaleUpdate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def SaleDelete(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_SaleServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "SaleCreate": grpc.unary_unary_rpc_method_handler(
            servicer.SaleCreate,
            request_deserializer=v1_dot_sales_dot_sale__pb2.SaleCreateRequest.FromString,
            response_serializer=v1_dot_sales_dot_sale__pb2.SaleCreateResponse.SerializeToString,
        ),
        "SaleRead": grpc.unary_unary_rpc_method_handler(
            servicer.SaleRead,
            request_deserializer=v1_dot_sales_dot_sale__pb2.SaleReadRequest.FromString,
            response_serializer=v1_dot_sales_dot_sale__pb2.SaleReadResponse.SerializeToString,
        ),
        "SaleUpdate": grpc.unary_unary_rpc_method_handler(
            servicer.SaleUpdate,
            request_deserializer=v1_dot_sales_dot_sale__pb2.SaleUpdateRequest.FromString,
            response_serializer=v1_dot_sales_dot_sale__pb2.SaleUpdateResponse.SerializeToString,
        ),
        "SaleDelete": grpc.unary_unary_rpc_method_handler(
            servicer.SaleDelete,
            request_deserializer=v1_dot_sales_dot_sale__pb2.SaleDeleteRequest.FromString,
            response_serializer=v1_dot_sales_dot_sale__pb2.SaleDeleteResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        "pro.omni.oms.api.v1.sales.sale.SaleService", rpc_method_handlers
    )
    server.add_generic_rpc_handlers((generic_handler,))


# This class is part of an EXPERIMENTAL API.
class SaleService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def SaleCreate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.sales.sale.SaleService/SaleCreate",
            v1_dot_sales_dot_sale__pb2.SaleCreateRequest.SerializeToString,
            v1_dot_sales_dot_sale__pb2.SaleCreateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def SaleRead(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.sales.sale.SaleService/SaleRead",
            v1_dot_sales_dot_sale__pb2.SaleReadRequest.SerializeToString,
            v1_dot_sales_dot_sale__pb2.SaleReadResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def SaleUpdate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.sales.sale.SaleService/SaleUpdate",
            v1_dot_sales_dot_sale__pb2.SaleUpdateRequest.SerializeToString,
            v1_dot_sales_dot_sale__pb2.SaleUpdateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def SaleDelete(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.sales.sale.SaleService/SaleDelete",
            v1_dot_sales_dot_sale__pb2.SaleDeleteRequest.SerializeToString,
            v1_dot_sales_dot_sale__pb2.SaleDeleteResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
from omni.pro.protos.v1.rules import category_pb2 as v1_dot_rules_dot_category__pb2


class CategoryServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CategoryCreate = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.category.CategoryService/CategoryCreate",
            request_serializer=v1_dot_rules_dot_category__pb2.CategoryCreateRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_category__pb2.CategoryCreateResponse.FromString,
        )
        self.CategoryRead = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.category.CategoryService/CategoryRead",
            request_serializer=v1_dot_rules_dot_category__pb2.CategoryReadRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_category__pb2.CategoryReadResponse.FromString,
        )
        self.CategoryUpdate = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.category.CategoryService/CategoryUpdate",
            request_serializer=v1_dot_rules_dot_category__pb2.CategoryUpdateRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_category__pb2.CategoryUpdateResponse.FromString,
        )
        self.CategoryDelete = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.category.CategoryService/CategoryDelete",
            request_serializer=v1_dot_rules_dot_category__pb2.CategoryDeleteRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_category__pb2.CategoryDeleteResponse.FromString,
        )


class CategoryServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def CategoryCreate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def CategoryRead(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def CategoryUpdate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def CategoryDelete(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_CategoryServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "CategoryCreate": grpc.unary_unary_rpc_method_handler(
            servicer.CategoryCreate,
            request_deserializer=v1_dot_rules_dot_category__pb2.CategoryCreateRequest.FromString,
            response_serializer=v1_dot_rules_dot_category__pb2.CategoryCreateResponse.SerializeToString,
        ),
        "CategoryRead": grpc.unary_unary_rpc_method_handler(
            servicer.CategoryRead,
            request_deserializer=v1_dot_rules_dot_category__pb2.CategoryReadRequest.FromString,
            response_serializer=v1_dot_rules_dot_category__pb2.CategoryReadResponse.SerializeToString,
        ),
        "CategoryUpdate": grpc.unary_unary_rpc_method_handler(
            servicer.CategoryUpdate,
            request_deserializer=v1_dot_rules_dot_category__pb2.CategoryUpdateRequest.FromString,
            response_serializer=v1_dot_rules_dot_category__pb2.CategoryUpdateResponse.SerializeToString,
        ),
        "CategoryDelete": grpc.unary_unary_rpc_method_handler(
            servicer.CategoryDelete,
            request_deserializer=v1_dot_rules_dot_category__pb2.CategoryDeleteRequest.FromString,
            response_serializer=v1_dot_rules_dot_category__pb2.CategoryDeleteResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        "pro.omni.oms.api.v1.rules.category.CategoryService", rpc_method_handlers
    )
    server.add_generic_rpc_handlers((generic_handler,))


# This class is part of an EXPERIMENTAL API.
class CategoryService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def CategoryCreate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.category.CategoryService/CategoryCreate",
            v1_dot_rules_dot_category__pb2.CategoryCreateRequest.SerializeToString,
            v1_dot_rules_dot_category__pb2.CategoryCreateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def CategoryRead(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.category.CategoryService/CategoryRead",
            v1_dot_rules_dot_category__pb2.CategoryReadRequest.SerializeToString,
            v1_dot_rules_dot_category__pb2.CategoryReadResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def CategoryUpdate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.category.CategoryService/CategoryUpdate",
            v1_dot_rules_dot_category__pb2.CategoryUpdateRequest.SerializeToString,
            v1_dot_rules_dot_category__pb2.CategoryUpdateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def CategoryDelete(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.category.CategoryService/CategoryDelete",
            v1_dot_rules_dot_category__pb2.CategoryDeleteRequest.SerializeToString,
            v1_dot_rules_dot_category__pb2.CategoryDeleteResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )
